@@ -76,12 +76,16 @@ def get_keycode(key: str) -> int:
         return -1
 
 class Status:
-    def __init__(self, info_dict: dict):
-        self.platform = info_dict['platform']
-        self.service = info_dict['service']
-        self.name = info_dict['name']
-        self.index = info_dict['index']
-        self.hwnd = info_dict['hwnd']
+    def __init__(self, info: Union[dict, int]):
+        if type(info) == dict:
+            self.platform = info['platform']
+            self.service = info['service']
+            self.name = info['name']
+            self.index = info['index']
+            self.hwnd = info['hwnd']
+        elif type(info) == int:
+            self.hwnd = info
+            self.name = f'窗口句柄{self.hwnd}'
 
         self.image_path = None
         self.model_path = None
@@ -272,6 +276,16 @@ class Status:
             res = postprocess_func(output)[0][0]
             return float(res) * face
 
+    def input(self, input_string: str):
+        """
+        对角色模拟输入操作
+        :param input_string: 模拟输入的内容
+        :return: 无返回值
+        """
+        input_char = [ord(c) for c in input_string]
+        for char in input_char:
+            ddtank.win32api.PostMessage(self.hwnd, ddtank.win32con.WM_CHAR, char, 0)
+
     # 条件识别
     def click_pixel(self, coordinate_x: int, coordinate_y: int, pixel: tuple, repeat: bool = True) -> bool:
         """
@@ -428,7 +442,7 @@ class Status:
         return white_box, blue_point
 
     # 顶级操作
-    def shot(self, shot_angle: Union[int, tuple], shot_strength: int, shot_item: str = None):
+    def shot(self, shot_angle: Union[int, tuple, list], shot_strength: int, shot_item: str = None):
         """
         综合模拟发射炮弹操作
         :param shot_angle: 发射的角度，若传递一个元组则执行变角操作
@@ -441,7 +455,7 @@ class Status:
         if type(shot_angle) == int:
             self.change_angle(self.ocr('angle'), shot_angle)
             self.press_shot(shot_strength)
-        elif type(shot_angle) == tuple:
+        elif type(shot_angle) == tuple or list:
             self.change_angle(self.ocr('angle'), shot_angle[0])
             self.press_shot(shot_strength)
             for i in range(1, len(shot_angle)):
